==> java.awt-1.0.3.jar: jdk/awt/font/NumericShaper$Range.clj <==
(ns jdk.awt.font.NumericShaper$Range
  (:refer-clojure :only [require comment defn ->])
  (:import [java.awt.font NumericShaper$Range]))

(def EUROPEAN
  "Enum Constant.

  The Latin (European) range with the Latin (ASCII) digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/EUROPEAN)

(def ARABIC
  "Enum Constant.

  The Arabic range with the Arabic-Indic digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/ARABIC)

(def EASTERN_ARABIC
  "Enum Constant.

  The Arabic range with the Eastern Arabic-Indic digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/EASTERN_ARABIC)

(def DEVANAGARI
  "Enum Constant.

  The Devanagari range with the Devanagari digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/DEVANAGARI)

(def BENGALI
  "Enum Constant.

  The Bengali range with the Bengali digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/BENGALI)

(def GURMUKHI
  "Enum Constant.

  The Gurmukhi range with the Gurmukhi digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/GURMUKHI)

(def GUJARATI
  "Enum Constant.

  The Gujarati range with the Gujarati digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/GUJARATI)

(def ORIYA
  "Enum Constant.

  The Oriya range with the Oriya digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/ORIYA)

(def TAMIL
  "Enum Constant.

  The Tamil range with the Tamil digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/TAMIL)

(def TELUGU
  "Enum Constant.

  The Telugu range with the Telugu digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/TELUGU)

(def KANNADA
  "Enum Constant.

  The Kannada range with the Kannada digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/KANNADA)

(def MALAYALAM
  "Enum Constant.

  The Malayalam range with the Malayalam digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/MALAYALAM)

(def THAI
  "Enum Constant.

  The Thai range with the Thai digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/THAI)

(def LAO
  "Enum Constant.

  The Lao range with the Lao digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/LAO)

(def TIBETAN
  "Enum Constant.

  The Tibetan range with the Tibetan digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/TIBETAN)

(def MYANMAR
  "Enum Constant.

  The Myanmar range with the Myanmar digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/MYANMAR)

(def ETHIOPIC
  "Enum Constant.

  The Ethiopic range with the Ethiopic digits. Ethiopic
   does not have a decimal digit 0 so Latin (European) 0 is
   used.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/ETHIOPIC)

(def KHMER
  "Enum Constant.

  The Khmer range with the Khmer digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/KHMER)

(def MONGOLIAN
  "Enum Constant.

  The Mongolian range with the Mongolian digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/MONGOLIAN)

(def NKO
  "Enum Constant.

  The N'Ko range with the N'Ko digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/NKO)

(def MYANMAR_SHAN
  "Enum Constant.

  The Myanmar range with the Myanmar Shan digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/MYANMAR_SHAN)

(def LIMBU
  "Enum Constant.

  The Limbu range with the Limbu digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/LIMBU)

(def NEW_TAI_LUE
  "Enum Constant.

  The New Tai Lue range with the New Tai Lue digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/NEW_TAI_LUE)

(def BALINESE
  "Enum Constant.

  The Balinese range with the Balinese digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/BALINESE)

(def SUNDANESE
  "Enum Constant.

  The Sundanese range with the Sundanese digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/SUNDANESE)

(def LEPCHA
  "Enum Constant.

  The Lepcha range with the Lepcha digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/LEPCHA)

(def OL_CHIKI
  "Enum Constant.

  The Ol Chiki range with the Ol Chiki digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/OL_CHIKI)

(def VAI
  "Enum Constant.

  The Vai range with the Vai digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/VAI)

(def SAURASHTRA
  "Enum Constant.

  The Saurashtra range with the Saurashtra digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/SAURASHTRA)

(def KAYAH_LI
  "Enum Constant.

  The Kayah Li range with the Kayah Li digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/KAYAH_LI)

(def CHAM
  "Enum Constant.

  The Cham range with the Cham digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/CHAM)

(def TAI_THAM_HORA
  "Enum Constant.

  The Tai Tham Hora range with the Tai Tham Hora digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/TAI_THAM_HORA)

(def TAI_THAM_THAM
  "Enum Constant.

  The Tai Tham Tham range with the Tai Tham Tham digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/TAI_THAM_THAM)

(def JAVANESE
  "Enum Constant.

  The Javanese range with the Javanese digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/JAVANESE)

(def MEETEI_MAYEK
  "Enum Constant.

  The Meetei Mayek range with the Meetei Mayek digits.

  type: java.awt.font.NumericShaper.Range"
  NumericShaper$Range/MEETEI_MAYEK)

(defn *values
  "Returns an array containing the constants of this enum type, in
  the order they are declared.  This method may be used to iterate
  over the constants as follows:


  for (NumericShaper.Range c : NumericShaper.Range.values())
      System.out.println(c);

  returns: an array containing the constants of this enum type, in the order they are declared - `java.awt.font.NumericShaper.Range[]`"
  ([]
    (NumericShaper$Range/values )))

(defn *value-of
  "Returns the enum constant of this type with the specified name.
  The string must match exactly an identifier used to declare an
  enum constant in this type.  (Extraneous whitespace characters are
  not permitted.)

  name - the name of the enum constant to be returned. - `java.lang.String`

  returns: the enum constant with the specified name - `java.awt.font.NumericShaper.Range`

  throws: java.lang.IllegalArgumentException - if this enum type has no constant with the specified name"
  (^java.awt.font.NumericShaper.Range [^java.lang.String name]
    (NumericShaper$Range/valueOf name)))

==> java.awt-1.0.4.jar: jdk/awt/font/NumericShaper$Range.clj <==
(ns jdk.awt.font.NumericShaper$Range
  (:refer-clojure :only [require comment defn ->])
  (:import [java.awt.font NumericShaper$Range]))

(def EUROPEAN
  "Enum Constant.

  The Latin (European) range with the Latin (ASCII) digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/EUROPEAN)

(def ARABIC
  "Enum Constant.

  The Arabic range with the Arabic-Indic digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/ARABIC)

(def EASTERN_ARABIC
  "Enum Constant.

  The Arabic range with the Eastern Arabic-Indic digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/EASTERN_ARABIC)

(def DEVANAGARI
  "Enum Constant.

  The Devanagari range with the Devanagari digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/DEVANAGARI)

(def BENGALI
  "Enum Constant.

  The Bengali range with the Bengali digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/BENGALI)

(def GURMUKHI
  "Enum Constant.

  The Gurmukhi range with the Gurmukhi digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/GURMUKHI)

(def GUJARATI
  "Enum Constant.

  The Gujarati range with the Gujarati digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/GUJARATI)

(def ORIYA
  "Enum Constant.

  The Oriya range with the Oriya digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/ORIYA)

(def TAMIL
  "Enum Constant.

  The Tamil range with the Tamil digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/TAMIL)

(def TELUGU
  "Enum Constant.

  The Telugu range with the Telugu digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/TELUGU)

(def KANNADA
  "Enum Constant.

  The Kannada range with the Kannada digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/KANNADA)

(def MALAYALAM
  "Enum Constant.

  The Malayalam range with the Malayalam digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/MALAYALAM)

(def THAI
  "Enum Constant.

  The Thai range with the Thai digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/THAI)

(def LAO
  "Enum Constant.

  The Lao range with the Lao digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/LAO)

(def TIBETAN
  "Enum Constant.

  The Tibetan range with the Tibetan digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/TIBETAN)

(def MYANMAR
  "Enum Constant.

  The Myanmar range with the Myanmar digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/MYANMAR)

(def ETHIOPIC
  "Enum Constant.

  The Ethiopic range with the Ethiopic digits. Ethiopic
   does not have a decimal digit 0 so Latin (European) 0 is
   used.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/ETHIOPIC)

(def KHMER
  "Enum Constant.

  The Khmer range with the Khmer digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/KHMER)

(def MONGOLIAN
  "Enum Constant.

  The Mongolian range with the Mongolian digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/MONGOLIAN)

(def NKO
  "Enum Constant.

  The N'Ko range with the N'Ko digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/NKO)

(def MYANMAR_SHAN
  "Enum Constant.

  The Myanmar range with the Myanmar Shan digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/MYANMAR_SHAN)

(def LIMBU
  "Enum Constant.

  The Limbu range with the Limbu digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/LIMBU)

(def NEW_TAI_LUE
  "Enum Constant.

  The New Tai Lue range with the New Tai Lue digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/NEW_TAI_LUE)

(def BALINESE
  "Enum Constant.

  The Balinese range with the Balinese digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/BALINESE)

(def SUNDANESE
  "Enum Constant.

  The Sundanese range with the Sundanese digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/SUNDANESE)

(def LEPCHA
  "Enum Constant.

  The Lepcha range with the Lepcha digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/LEPCHA)

(def OL_CHIKI
  "Enum Constant.

  The Ol Chiki range with the Ol Chiki digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/OL_CHIKI)

(def VAI
  "Enum Constant.

  The Vai range with the Vai digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/VAI)

(def SAURASHTRA
  "Enum Constant.

  The Saurashtra range with the Saurashtra digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/SAURASHTRA)

(def KAYAH_LI
  "Enum Constant.

  The Kayah Li range with the Kayah Li digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/KAYAH_LI)

(def CHAM
  "Enum Constant.

  The Cham range with the Cham digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/CHAM)

(def TAI_THAM_HORA
  "Enum Constant.

  The Tai Tham Hora range with the Tai Tham Hora digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/TAI_THAM_HORA)

(def TAI_THAM_THAM
  "Enum Constant.

  The Tai Tham Tham range with the Tai Tham Tham digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/TAI_THAM_THAM)

(def JAVANESE
  "Enum Constant.

  The Javanese range with the Javanese digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/JAVANESE)

(def MEETEI_MAYEK
  "Enum Constant.

  The Meetei Mayek range with the Meetei Mayek digits.

  type: java.awt.font.NumericShaper$Range"
  NumericShaper$Range/MEETEI_MAYEK)

(defn *values
  "Returns an array containing the constants of this enum type, in
  the order they are declared.  This method may be used to iterate
  over the constants as follows:


  for (NumericShaper.Range c : NumericShaper.Range.values())
      System.out.println(c);

  returns: an array containing the constants of this enum type, in the order they are declared - `java.awt.font.NumericShaper$Range[]`"
  ([]
    (NumericShaper$Range/values )))

(defn *value-of
  "Returns the enum constant of this type with the specified name.
  The string must match exactly an identifier used to declare an
  enum constant in this type.  (Extraneous whitespace characters are
  not permitted.)

  name - the name of the enum constant to be returned. - `java.lang.String`

  returns: the enum constant with the specified name - `java.awt.font.NumericShaper$Range`

  throws: java.lang.IllegalArgumentException - if this enum type has no constant with the specified name"
  (^java.awt.font.NumericShaper$Range [^java.lang.String name]
    (NumericShaper$Range/valueOf name)))
